// For any NPQs discovered in the past 7 days, create a new case.
@isTest
public class BackupTest_NPQCase {
    
    @isTest static void createCaseWithNPQDisclosure()
    {
        Account a = new Account(Name='test', NPQ_Disclosure_Required__c = true, NPQ_Realized_Date__c = date.today());
        insert a;
        Test.startTest();
        BackupNPQCase.evaluateNPQ(a);
        Test.stopTest();        
        List<Case> casesfound = [SELECT id FROM case];
        system.assertEquals(1,casesfound.size(),'No cases were found');
    }

    @isTest static void noCaseWithoutNPQDisclosure()
    {
        Account a = new Account(Name='test', NPQ_Disclosure_Required__c = false);
        insert a;
        Test.startTest();
        BackupNPQCase.evaluateNPQ(a);
        Test.stopTest();
        List<Case> casesfound = [SELECT id FROM case];
        system.assertEquals(0,casesfound.size(),'A case was found');
    }
    
    @isTest static void noCaseWithOldNPQDisclosure()
    {
        Account a = new Account(Name='test', NPQ_Disclosure_Required__c = true, NPQ_Realized_Date__c = date.today().adddays(-8));
        insert a;
        Test.startTest();
        BackupNPQCase.evaluateNPQ(a);
        Test.stopTest();
        List<Case> casesfound = [SELECT id FROM case];
        system.assertEquals(0,casesfound.size(),'A case was found');
    }
    
    @isTest static void bulkCreateCaseWithNPQDisclosure()
    {
        Integer i = 0;
        List<Account>acclist = new List<Account>();
        for(i = 0; i < 100; i++)
        {
            Account a = new Account(Name='test',NPQ_Disclosure_Required__c = true, NPQ_Realized_Date__c = date.today());
            acclist.add(a);
        }
        for(i = 0; i < 100; i++)
        {
            Account a = new Account(Name='test',NPQ_Disclosure_Required__c = false, NPQ_Realized_Date__c = date.today());
            acclist.add(a);
        }
        insert acclist;
        Test.startTest();
        BackupNPQCase.evaluateNPQ(acclist);
        Test.stopTest();
        List<Case> casesfound = [SELECT id FROM case];
        system.assertEquals(100,casesfound.size(),'Did not find 100 cases');
    }
    
}